Crate castlecore

Crate castlecore 

CastleCore

Core Engine for development (Altenstein and same projects.) Will pack with map (and same) editor base on CastleCore.

Modules

core
A module containing all the core functions (temporary description)
functions
A temporary module for debugging functions.
render
A module containing all the functions related to the render (temporary description)
screen
A module containing all the functions related to the screen (temporary description)
window
A module containing all the functions related to the borders (temporary description)

Functions

cc_ver
Return current CastleCore version